imblearn.under_sampling.NearMiss
================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: NearMiss

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NearMiss.__init__
      ~NearMiss.fit
      ~NearMiss.fit_sample
      ~NearMiss.get_params
      ~NearMiss.sample
      ~NearMiss.set_params
   
   

   
   
   